==> haskell-placeholders-0.1-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-placeholders.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: placeholders
version: 0.1
id: placeholders-0.1-Jaw2KlzCEKg3F0WJS0H8eo
key: placeholders-0.1-Jaw2KlzCEKg3F0WJS0H8eo
license: BSD3
copyright: (c) 2011 Andreas Hammar
maintainer: Andreas Hammar <ahammar@gmail.com>
homepage: http://github.com/ahammar/placeholders
synopsis: Placeholders for use while developing Haskell code
description:
    While working on some Haskell code, it is often useful to
    work incrementally by inserting @undefined@ as a
    placeholder for missing code.
    .
    This library provides placeholders that produce better
    messages when evaluated at run-time and also generate
    compile-time warnings so that they do not get forgotten
    so easily.
    For details, see <http://github.com/ahammar/placeholders>
category: Development
author: Andreas Hammar
exposed: True
exposed-modules:
    Development.Placeholders
abi: f7ed1e635d952c71948bee11d2f1e42a
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/placeholders-0.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/placeholders-0.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/placeholders-0.1
hs-libraries: HSplaceholders-0.1-Jaw2KlzCEKg3F0WJS0H8eo
depends:
    base-4.9.0.0 template-haskell-2.11.0.0
haddock-interfaces: /usr/share/doc/haskell-placeholders/html/placeholders.haddock
haddock-html: /usr/share/doc/haskell-placeholders/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-placeholders-0.1-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-placeholders.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: placeholders
version: 0.1
id: placeholders-0.1-LDJrwU9ZofA2sH3wxupcG1
key: placeholders-0.1-LDJrwU9ZofA2sH3wxupcG1
license: BSD3
copyright: (c) 2011 Andreas Hammar
maintainer: Andreas Hammar <ahammar@gmail.com>
homepage: http://github.com/ahammar/placeholders
synopsis: Placeholders for use while developing Haskell code
description:
    While working on some Haskell code, it is often useful to
    work incrementally by inserting @undefined@ as a
    placeholder for missing code.
    .
    This library provides placeholders that produce better
    messages when evaluated at run-time and also generate
    compile-time warnings so that they do not get forgotten
    so easily.
    For details, see <http://github.com/ahammar/placeholders>
category: Development
author: Andreas Hammar
exposed: True
exposed-modules:
    Development.Placeholders
abi: 2de6677c84ae7823adc7b8da7a9982a6
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/placeholders-0.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/placeholders-0.1
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/placeholders-0.1
hs-libraries: HSplaceholders-0.1-LDJrwU9ZofA2sH3wxupcG1
depends:
    base-4.9.1.0 template-haskell-2.11.1.0
haddock-interfaces: /usr/share/doc/haskell-placeholders/html/placeholders.haddock
haddock-html: /usr/share/doc/haskell-placeholders/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
